Class: Decidim::Meetings::Meeting
- Inherits:
-
ApplicationRecord
- Object
- ActiveRecord::Base
- ApplicationRecord
- Decidim::Meetings::Meeting
- Includes:
- ActsAsAuthor, Authorable, Comments::CommentableWithComponent, Comments::HasAvailabilityAttributes, FilterableResource, Followable, Forms::HasQuestionnaire, HasAttachmentCollections, HasAttachments, HasCategory, HasComponent, HasReference, Loggable, Paddable, Publicable, Reportable, Resourceable, ScopableResource, Searchable, Traceable, TranslatableResource
- Defined in:
- app/models/decidim/meetings/meeting.rb
Overview
The data store for a Meeting in the Decidim::Meetings component. It stores a title, description and any other useful information to render a custom meeting.
Constant Summary collapse
- TYPE_OF_MEETING =
{ in_person: 0, online: 10, hybrid: 20 }.freeze
- REGISTRATION_TYPES =
{ registration_disabled: 0, on_this_platform: 10, on_different_platform: 20 }.freeze
Class Method Summary collapse
- .log_presenter_class_for(_log) ⇒ Object
- .participants_iframe_embed_types ⇒ Object
- .ransack(params = {}, options = {}) ⇒ Object
- .ransackable_scopes(_auth_object = nil) ⇒ Object
- .sort_by_translated_title_asc ⇒ Object
- .sort_by_translated_title_desc ⇒ Object
Instance Method Summary collapse
-
#accepts_new_comments? ⇒ Boolean
Public: Overrides the ‘accepts_new_comments?` CommentableWithComponent concern method.
-
#allow_resource_permissions? ⇒ Boolean
Public: Overrides the ‘allow_resource_permissions?` Resourceable concern method.
- #authored_proposals ⇒ Object
- #can_be_joined_by?(user) ⇒ Boolean
- #can_participate?(user) ⇒ Boolean
- #can_register_invitation?(user) ⇒ Boolean
- #closed? ⇒ Boolean
-
#comments_have_alignment? ⇒ Boolean
Public: Overrides the ‘comments_have_alignment?` Commentable concern method.
-
#comments_have_votes? ⇒ Boolean
Public: Overrides the ‘comments_have_votes?` Commentable concern method.
- #current_user_can_visit_meeting?(user) ⇒ Boolean
- #emendation? ⇒ Boolean
- #has_attendees? ⇒ Boolean
- #has_available_slots? ⇒ Boolean
- #has_contributions? ⇒ Boolean
- #has_registration_for?(user) ⇒ Boolean
- #iframe_access_level_allowed_for_user?(user) ⇒ Boolean
- #live? ⇒ Boolean
- #maps_enabled? ⇒ Boolean
-
#meeting_duration ⇒ Object
Return the duration of the meeting in minutes.
-
#pad_is_visible? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when to display a pad or not.
-
#pad_is_writable? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when a pad is writable or not.
- #past? ⇒ Boolean
-
#presenter ⇒ Object
Returns the presenter for this author, to be used in the views.
- #remaining_slots ⇒ Object
-
#reported_attributes ⇒ Object
Public: Overrides the ‘reported_attributes` Reportable concern method.
-
#reported_searchable_content_extras ⇒ Object
Public: Overrides the ‘reported_searchable_content_extras` Reportable concern method.
- #resource_visible? ⇒ Boolean
- #started? ⇒ Boolean
-
#user_group_registrations ⇒ Object
Return registrations of a particular meeting made by users representing a group.
-
#users_to_notify_on_comment_created ⇒ Object
Public: Override Commentable concern method ‘users_to_notify_on_comment_created`.
-
#withdrawable_by?(user) ⇒ Boolean
Checks whether the user can withdraw the given meeting.
-
#withdrawn? ⇒ Boolean
Public: Checks if the author has withdrawn the meeting.
Class Method Details
.log_presenter_class_for(_log) ⇒ Object
168 169 170 |
# File 'app/models/decidim/meetings/meeting.rb', line 168 def self.log_presenter_class_for(_log) Decidim::Meetings::AdminLog::MeetingPresenter end |
.participants_iframe_embed_types ⇒ Object
153 154 155 |
# File 'app/models/decidim/meetings/meeting.rb', line 153 def self. .except(:open_in_live_event_page) end |
.ransack(params = {}, options = {}) ⇒ Object
365 366 367 |
# File 'app/models/decidim/meetings/meeting.rb', line 365 def self.ransack(params = {}, = {}) MeetingSearch.new(self, params, ) end |
.ransackable_scopes(_auth_object = nil) ⇒ Object
361 362 363 |
# File 'app/models/decidim/meetings/meeting.rb', line 361 def self.ransackable_scopes(_auth_object = nil) [:with_any_type, :with_any_date, :with_any_space, :with_any_origin, :with_any_scope, :with_any_category, :with_any_global_category] end |
.sort_by_translated_title_asc ⇒ Object
339 340 341 342 |
# File 'app/models/decidim/meetings/meeting.rb', line 339 def self.sort_by_translated_title_asc field = Arel::Nodes::InfixOperation.new("->>", arel_table[:title], Arel::Nodes.build_quoted(I18n.locale)) order(Arel::Nodes::InfixOperation.new("", field, Arel.sql("ASC"))) end |
.sort_by_translated_title_desc ⇒ Object
344 345 346 347 |
# File 'app/models/decidim/meetings/meeting.rb', line 344 def self.sort_by_translated_title_desc field = Arel::Nodes::InfixOperation.new("->>", arel_table[:title], Arel::Nodes.build_quoted(I18n.locale)) order(Arel::Nodes::InfixOperation.new("", field, Arel.sql("DESC"))) end |
Instance Method Details
#accepts_new_comments? ⇒ Boolean
Public: Overrides the ‘accepts_new_comments?` CommentableWithComponent concern method.
216 217 218 |
# File 'app/models/decidim/meetings/meeting.rb', line 216 def accepts_new_comments? commentable? && !component.current_settings.comments_blocked && comments_allowed? end |
#allow_resource_permissions? ⇒ Boolean
Public: Overrides the ‘allow_resource_permissions?` Resourceable concern method.
221 222 223 |
# File 'app/models/decidim/meetings/meeting.rb', line 221 def component.settings. end |
#authored_proposals ⇒ Object
301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'app/models/decidim/meetings/meeting.rb', line 301 def return [] unless Decidim::Meetings.enable_proposal_linking Decidim::Proposals::Proposal .joins(:coauthorships) .where( decidim_coauthorships: { decidim_author_type: "Decidim::Meetings::Meeting", decidim_author_id: id } ) end |
#can_be_joined_by?(user) ⇒ Boolean
172 173 174 |
# File 'app/models/decidim/meetings/meeting.rb', line 172 def can_be_joined_by?(user) !started? && registrations_enabled? && can_participate?(user) end |
#can_participate?(user) ⇒ Boolean
240 241 242 |
# File 'app/models/decidim/meetings/meeting.rb', line 240 def can_participate?(user) can_participate_in_space?(user) && can_participate_in_meeting?(user) end |
#can_register_invitation?(user) ⇒ Boolean
176 177 178 179 |
# File 'app/models/decidim/meetings/meeting.rb', line 176 def can_register_invitation?(user) !closed? && registrations_enabled? && can_participate_in_space?(user) && user_has_invitation_for_meeting?(user) end |
#closed? ⇒ Boolean
181 182 183 |
# File 'app/models/decidim/meetings/meeting.rb', line 181 def closed? closed_at.present? end |
#comments_have_alignment? ⇒ Boolean
Public: Overrides the ‘comments_have_alignment?` Commentable concern method.
226 227 228 |
# File 'app/models/decidim/meetings/meeting.rb', line 226 def comments_have_alignment? true end |
#comments_have_votes? ⇒ Boolean
Public: Overrides the ‘comments_have_votes?` Commentable concern method.
231 232 233 |
# File 'app/models/decidim/meetings/meeting.rb', line 231 def comments_have_votes? true end |
#current_user_can_visit_meeting?(user) ⇒ Boolean
244 245 246 |
# File 'app/models/decidim/meetings/meeting.rb', line 244 def current_user_can_visit_meeting?(user) Decidim::Meetings::Meeting.visible_for(user).exists?(id:) end |
#emendation? ⇒ Boolean
193 194 195 |
# File 'app/models/decidim/meetings/meeting.rb', line 193 def emendation? false end |
#has_attendees? ⇒ Boolean
328 329 330 |
# File 'app/models/decidim/meetings/meeting.rb', line 328 def has_attendees? !!attendees_count && attendees_count.positive? end |
#has_available_slots? ⇒ Boolean
197 198 199 200 201 |
# File 'app/models/decidim/meetings/meeting.rb', line 197 def has_available_slots? return true if available_slots.zero? (available_slots - reserved_slots) > registrations.count end |
#has_contributions? ⇒ Boolean
324 325 326 |
# File 'app/models/decidim/meetings/meeting.rb', line 324 def has_contributions? !!contributions_count && contributions_count.positive? end |
#has_registration_for?(user) ⇒ Boolean
207 208 209 |
# File 'app/models/decidim/meetings/meeting.rb', line 207 def has_registration_for?(user) registrations.where(user:).any? end |
#iframe_access_level_allowed_for_user?(user) ⇒ Boolean
248 249 250 251 252 253 254 255 256 257 |
# File 'app/models/decidim/meetings/meeting.rb', line 248 def iframe_access_level_allowed_for_user?(user) case iframe_access_level when "all" true when "signed_in" user.present? else has_registration_for?(user) end end |
#live? ⇒ Boolean
332 333 334 335 336 337 |
# File 'app/models/decidim/meetings/meeting.rb', line 332 def live? start_time && end_time && Time.current >= (start_time - 10.minutes) && Time.current <= end_time end |
#maps_enabled? ⇒ Boolean
211 212 213 |
# File 'app/models/decidim/meetings/meeting.rb', line 211 def maps_enabled? component.settings.maps_enabled? end |
#meeting_duration ⇒ Object
Return the duration of the meeting in minutes
260 261 262 |
# File 'app/models/decidim/meetings/meeting.rb', line 260 def meeting_duration @meeting_duration ||= ((end_time - start_time) / 1.minute).abs end |
#pad_is_visible? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when to display a pad or not.
287 288 289 290 291 |
# File 'app/models/decidim/meetings/meeting.rb', line 287 def pad_is_visible? return false unless pad (start_time - Time.current) <= 24.hours end |
#pad_is_writable? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when a pad is writable or not.
295 296 297 298 299 |
# File 'app/models/decidim/meetings/meeting.rb', line 295 def pad_is_writable? return false unless pad_is_visible? (Time.current - end_time) < 72.hours end |
#past? ⇒ Boolean
189 190 191 |
# File 'app/models/decidim/meetings/meeting.rb', line 189 def past? end_time < Time.current end |
#presenter ⇒ Object
Returns the presenter for this author, to be used in the views. Required by ActsAsAuthor.
164 165 166 |
# File 'app/models/decidim/meetings/meeting.rb', line 164 def presenter Decidim::Meetings::MeetingPresenter.new(self) end |
#remaining_slots ⇒ Object
203 204 205 |
# File 'app/models/decidim/meetings/meeting.rb', line 203 def remaining_slots available_slots - reserved_slots - registrations.count end |
#reported_attributes ⇒ Object
Public: Overrides the ‘reported_attributes` Reportable concern method.
315 316 317 |
# File 'app/models/decidim/meetings/meeting.rb', line 315 def reported_attributes [:description] end |
#reported_searchable_content_extras ⇒ Object
Public: Overrides the ‘reported_searchable_content_extras` Reportable concern method.
320 321 322 |
# File 'app/models/decidim/meetings/meeting.rb', line 320 def reported_searchable_content_extras [.name] end |
#resource_visible? ⇒ Boolean
264 265 266 267 268 |
# File 'app/models/decidim/meetings/meeting.rb', line 264 def resource_visible? return false if hidden? !private_meeting? || transparent? end |
#started? ⇒ Boolean
185 186 187 |
# File 'app/models/decidim/meetings/meeting.rb', line 185 def started? start_time < Time.current end |
#user_group_registrations ⇒ Object
Return registrations of a particular meeting made by users representing a group
158 159 160 |
# File 'app/models/decidim/meetings/meeting.rb', line 158 def user_group_registrations registrations.where.not(decidim_user_group_id: nil) end |
#users_to_notify_on_comment_created ⇒ Object
Public: Override Commentable concern method ‘users_to_notify_on_comment_created`
236 237 238 |
# File 'app/models/decidim/meetings/meeting.rb', line 236 def users_to_notify_on_comment_created followers end |
#withdrawable_by?(user) ⇒ Boolean
Checks whether the user can withdraw the given meeting.
user - the user to check for withdrawability. past meetings cannot be withdrawn
281 282 283 |
# File 'app/models/decidim/meetings/meeting.rb', line 281 def withdrawable_by?(user) user && !withdrawn? && !past? && (user) end |
#withdrawn? ⇒ Boolean
Public: Checks if the author has withdrawn the meeting.
Returns Boolean.
273 274 275 |
# File 'app/models/decidim/meetings/meeting.rb', line 273 def withdrawn? state == "withdrawn" end |