Class: Decidim::Meetings::Meeting
- Inherits:
-
ApplicationRecord
- Object
- ActiveRecord::Base
- ApplicationRecord
- Decidim::Meetings::Meeting
- Includes:
- ActsAsAuthor, Authorable, Comments::CommentableWithComponent, Comments::HasAvailabilityAttributes, Followable, Forms::HasQuestionnaire, HasAttachmentCollections, HasAttachments, HasCategory, HasComponent, HasReference, Loggable, Paddable, Publicable, Reportable, Resourceable, ScopableResource, Searchable, Traceable, TranslatableResource
- Defined in:
- app/models/decidim/meetings/meeting.rb
Overview
The data store for a Meeting in the Decidim::Meetings component. It stores a title, description and any other useful information to render a custom meeting.
Constant Summary collapse
- TYPE_OF_MEETING =
%w(in_person online hybrid).freeze
- REGISTRATION_TYPE =
%w(registration_disabled on_this_platform on_different_platform).freeze
Class Method Summary collapse
- .log_presenter_class_for(_log) ⇒ Object
- .participants_iframe_embed_types ⇒ Object
- .sort_by_translated_title_asc ⇒ Object
- .sort_by_translated_title_desc ⇒ Object
Instance Method Summary collapse
-
#accepts_new_comments? ⇒ Boolean
Public: Overrides the `accepts_new_comments?` CommentableWithComponent concern method.
-
#allow_resource_permissions? ⇒ Boolean
Public: Overrides the `allow_resource_permissions?` Resourceable concern method.
- #authored_proposals ⇒ Object
- #can_be_joined_by?(user) ⇒ Boolean
- #can_participate?(user) ⇒ Boolean
- #can_register_invitation?(user) ⇒ Boolean
- #closed? ⇒ Boolean
-
#comments_have_alignment? ⇒ Boolean
Public: Overrides the `comments_have_alignment?` Commentable concern method.
-
#comments_have_votes? ⇒ Boolean
Public: Overrides the `comments_have_votes?` Commentable concern method.
- #current_user_can_visit_meeting?(user) ⇒ Boolean
- #emendation? ⇒ Boolean
- #has_attendees? ⇒ Boolean
- #has_available_slots? ⇒ Boolean
- #has_contributions? ⇒ Boolean
- #has_registration_for?(user) ⇒ Boolean
- #iframe_access_level_allowed_for_user?(user) ⇒ Boolean
- #live? ⇒ Boolean
- #maps_enabled? ⇒ Boolean
-
#meeting_duration ⇒ Object
Return the duration of the meeting in minutes.
- #on_different_platform? ⇒ Boolean
- #on_this_platform? ⇒ Boolean
-
#pad_is_visible? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when to display a pad or not.
-
#pad_is_writable? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when a pad is writable or not.
- #past? ⇒ Boolean
-
#presenter ⇒ Object
Returns the presenter for this author, to be used in the views.
- #registration_disabled? ⇒ Boolean
- #remaining_slots ⇒ Object
-
#reported_attributes ⇒ Object
Public: Overrides the `reported_attributes` Reportable concern method.
-
#reported_content_url ⇒ Object
Public: Overrides the `reported_content_url` Reportable concern method.
-
#reported_searchable_content_extras ⇒ Object
Public: Overrides the `reported_searchable_content_extras` Reportable concern method.
- #resource_visible? ⇒ Boolean
-
#user_group_registrations ⇒ Object
Return registrations of a particular meeting made by users representing a group.
-
#users_to_notify_on_comment_created ⇒ Object
Public: Override Commentable concern method `users_to_notify_on_comment_created`.
-
#withdrawable_by?(user) ⇒ Boolean
Checks whether the user can withdraw the given meeting.
-
#withdrawn? ⇒ Boolean
Public: Checks if the author has withdrawn the meeting.
Class Method Details
.log_presenter_class_for(_log) ⇒ Object
145 146 147 |
# File 'app/models/decidim/meetings/meeting.rb', line 145 def self.log_presenter_class_for(_log) Decidim::Meetings::AdminLog::MeetingPresenter end |
.participants_iframe_embed_types ⇒ Object
130 131 132 |
# File 'app/models/decidim/meetings/meeting.rb', line 130 def self. .except(:open_in_live_event_page) end |
.sort_by_translated_title_asc ⇒ Object
335 336 337 338 |
# File 'app/models/decidim/meetings/meeting.rb', line 335 def self.sort_by_translated_title_asc field = Arel::Nodes::InfixOperation.new("->>", arel_table[:title], Arel::Nodes.build_quoted(I18n.locale)) order(Arel::Nodes::InfixOperation.new("", field, Arel.sql("ASC"))) end |
.sort_by_translated_title_desc ⇒ Object
340 341 342 343 |
# File 'app/models/decidim/meetings/meeting.rb', line 340 def self.sort_by_translated_title_desc field = Arel::Nodes::InfixOperation.new("->>", arel_table[:title], Arel::Nodes.build_quoted(I18n.locale)) order(Arel::Nodes::InfixOperation.new("", field, Arel.sql("DESC"))) end |
Instance Method Details
#accepts_new_comments? ⇒ Boolean
Public: Overrides the `accepts_new_comments?` CommentableWithComponent concern method.
189 190 191 |
# File 'app/models/decidim/meetings/meeting.rb', line 189 def accepts_new_comments? commentable? && !component.current_settings.comments_blocked && comments_allowed? end |
#allow_resource_permissions? ⇒ Boolean
Public: Overrides the `allow_resource_permissions?` Resourceable concern method.
194 195 196 |
# File 'app/models/decidim/meetings/meeting.rb', line 194 def component.settings. end |
#authored_proposals ⇒ Object
274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'app/models/decidim/meetings/meeting.rb', line 274 def return [] unless Decidim::Meetings.enable_proposal_linking Decidim::Proposals::Proposal .joins(:coauthorships) .where( decidim_coauthorships: { decidim_author_type: "Decidim::Meetings::Meeting", decidim_author_id: id } ) end |
#can_be_joined_by?(user) ⇒ Boolean
149 150 151 |
# File 'app/models/decidim/meetings/meeting.rb', line 149 def can_be_joined_by?(user) !closed? && registrations_enabled? && can_participate?(user) end |
#can_participate?(user) ⇒ Boolean
213 214 215 |
# File 'app/models/decidim/meetings/meeting.rb', line 213 def can_participate?(user) can_participate_in_space?(user) && can_participate_in_meeting?(user) end |
#can_register_invitation?(user) ⇒ Boolean
153 154 155 156 |
# File 'app/models/decidim/meetings/meeting.rb', line 153 def can_register_invitation?(user) !closed? && registrations_enabled? && can_participate_in_space?(user) && user_has_invitation_for_meeting?(user) end |
#closed? ⇒ Boolean
158 159 160 |
# File 'app/models/decidim/meetings/meeting.rb', line 158 def closed? closed_at.present? end |
#comments_have_alignment? ⇒ Boolean
Public: Overrides the `comments_have_alignment?` Commentable concern method.
199 200 201 |
# File 'app/models/decidim/meetings/meeting.rb', line 199 def comments_have_alignment? true end |
#comments_have_votes? ⇒ Boolean
Public: Overrides the `comments_have_votes?` Commentable concern method.
204 205 206 |
# File 'app/models/decidim/meetings/meeting.rb', line 204 def comments_have_votes? true end |
#current_user_can_visit_meeting?(user) ⇒ Boolean
217 218 219 |
# File 'app/models/decidim/meetings/meeting.rb', line 217 def current_user_can_visit_meeting?(user) Decidim::Meetings::Meeting.visible_meeting_for(user).exists?(id: id) end |
#emendation? ⇒ Boolean
166 167 168 |
# File 'app/models/decidim/meetings/meeting.rb', line 166 def emendation? false end |
#has_attendees? ⇒ Boolean
324 325 326 |
# File 'app/models/decidim/meetings/meeting.rb', line 324 def has_attendees? !!attendees_count && attendees_count.positive? end |
#has_available_slots? ⇒ Boolean
170 171 172 173 174 |
# File 'app/models/decidim/meetings/meeting.rb', line 170 def has_available_slots? return true if available_slots.zero? (available_slots - reserved_slots) > registrations.count end |
#has_contributions? ⇒ Boolean
320 321 322 |
# File 'app/models/decidim/meetings/meeting.rb', line 320 def has_contributions? !!contributions_count && contributions_count.positive? end |
#has_registration_for?(user) ⇒ Boolean
180 181 182 |
# File 'app/models/decidim/meetings/meeting.rb', line 180 def has_registration_for?(user) registrations.where(user: user).any? end |
#iframe_access_level_allowed_for_user?(user) ⇒ Boolean
221 222 223 224 225 226 227 228 229 230 |
# File 'app/models/decidim/meetings/meeting.rb', line 221 def iframe_access_level_allowed_for_user?(user) case iframe_access_level when "all" true when "signed_in" user.present? else has_registration_for?(user) end end |
#live? ⇒ Boolean
328 329 330 331 332 333 |
# File 'app/models/decidim/meetings/meeting.rb', line 328 def live? start_time && end_time && Time.current >= (start_time - 10.minutes) && Time.current <= end_time end |
#maps_enabled? ⇒ Boolean
184 185 186 |
# File 'app/models/decidim/meetings/meeting.rb', line 184 def maps_enabled? component.settings.maps_enabled? end |
#meeting_duration ⇒ Object
Return the duration of the meeting in minutes
233 234 235 |
# File 'app/models/decidim/meetings/meeting.rb', line 233 def meeting_duration @meeting_duration ||= ((end_time - start_time) / 1.minute).abs end |
#on_different_platform? ⇒ Boolean
316 317 318 |
# File 'app/models/decidim/meetings/meeting.rb', line 316 def on_different_platform? registration_type == "on_different_platform" end |
#on_this_platform? ⇒ Boolean
312 313 314 |
# File 'app/models/decidim/meetings/meeting.rb', line 312 def on_this_platform? registration_type == "on_this_platform" end |
#pad_is_visible? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when to display a pad or not.
260 261 262 263 264 |
# File 'app/models/decidim/meetings/meeting.rb', line 260 def pad_is_visible? return false unless pad (start_time - Time.current) <= 24.hours end |
#pad_is_writable? ⇒ Boolean
Overwrites method from Paddable to add custom rules in order to know when a pad is writable or not.
268 269 270 271 272 |
# File 'app/models/decidim/meetings/meeting.rb', line 268 def pad_is_writable? return false unless pad_is_visible? (Time.current - end_time) < 72.hours end |
#past? ⇒ Boolean
162 163 164 |
# File 'app/models/decidim/meetings/meeting.rb', line 162 def past? end_time < Time.current end |
#presenter ⇒ Object
Returns the presenter for this author, to be used in the views. Required by ActsAsAuthor.
141 142 143 |
# File 'app/models/decidim/meetings/meeting.rb', line 141 def presenter Decidim::Meetings::MeetingPresenter.new(self) end |
#registration_disabled? ⇒ Boolean
308 309 310 |
# File 'app/models/decidim/meetings/meeting.rb', line 308 def registration_disabled? registration_type == "registration_disabled" end |
#remaining_slots ⇒ Object
176 177 178 |
# File 'app/models/decidim/meetings/meeting.rb', line 176 def remaining_slots available_slots - reserved_slots - registrations.count end |
#reported_attributes ⇒ Object
Public: Overrides the `reported_attributes` Reportable concern method.
293 294 295 |
# File 'app/models/decidim/meetings/meeting.rb', line 293 def reported_attributes [:description] end |
#reported_content_url ⇒ Object
Public: Overrides the `reported_content_url` Reportable concern method.
288 289 290 |
# File 'app/models/decidim/meetings/meeting.rb', line 288 def reported_content_url ResourceLocatorPresenter.new(self).url end |
#reported_searchable_content_extras ⇒ Object
Public: Overrides the `reported_searchable_content_extras` Reportable concern method.
298 299 300 |
# File 'app/models/decidim/meetings/meeting.rb', line 298 def reported_searchable_content_extras [.name] end |
#resource_visible? ⇒ Boolean
237 238 239 240 241 |
# File 'app/models/decidim/meetings/meeting.rb', line 237 def resource_visible? return false if hidden? !private_meeting? || transparent? end |
#user_group_registrations ⇒ Object
Return registrations of a particular meeting made by users representing a group
135 136 137 |
# File 'app/models/decidim/meetings/meeting.rb', line 135 def user_group_registrations registrations.where.not(decidim_user_group_id: nil) end |
#users_to_notify_on_comment_created ⇒ Object
Public: Override Commentable concern method `users_to_notify_on_comment_created`
209 210 211 |
# File 'app/models/decidim/meetings/meeting.rb', line 209 def users_to_notify_on_comment_created followers end |
#withdrawable_by?(user) ⇒ Boolean
Checks whether the user can withdraw the given meeting.
user - the user to check for withdrawability. past meetings cannot be withdrawn
254 255 256 |
# File 'app/models/decidim/meetings/meeting.rb', line 254 def withdrawable_by?(user) user && !withdrawn? && !past? && (user) end |
#withdrawn? ⇒ Boolean
Public: Checks if the author has withdrawn the meeting.
Returns Boolean.
246 247 248 |
# File 'app/models/decidim/meetings/meeting.rb', line 246 def withdrawn? state == "withdrawn" end |